import request from './request.js'
// 签到
export function checkIn(data = {}) {
  return request.post('/in',data)
}
// 收藏列表
export function collectList(data = {}) {
  return request.get('/collect/list',data)
}
// 收藏数
export function queryCollectCount(data = {}) {
  return request.get('/collect/queryCollectCount',data)
}

// 查询会员类型
export function vipList(data = {}) {
  return request.get('/type/list',data)
}


// 会员权限
export function privilege(data = {}) {
  return request.get(`/type/privilege/${data}`)
}

// 查询我的报名记录列表
export function getWorkflowApplyByUserId(data = {}) {
  return request.get('/apply/getWorkflowApplyByUserId',data)
}

// 查询报名记录列表
export function appliList(data = {}) {
  return request.get('/apply/list',data)
}

// 查询登录用户的寻找工作流列表
export function userQuestList(data = {}) {
  return request.get('/quest/userQuestList',data)
}

// 删除登录用户的寻找工作流信息
export function delectQuest(data = {}) {
  return request.del(`/quest/${data}`)
}

// 结束需求
export function updateQuestStatus(data = {}) {
  return request.put(`/quest/updateQuestStatus`,data)
}

// 拒绝同意
export function applyUpdateQuestStatus(data = {}) {
  return request.put(`/apply/updateStatus`,data)
}

// 取消报名
export function cancelApply(data = {}) {
  return request.del(`/apply/${data}`)
}

// 我的订单
export function orderList(data = {}) {
  return request.get('/order/list',data)
}

// 我的发票
export function invoiceList(data = {}) {
  return request.get('/invoice/list',data)
}
// 申请发票
export function applyInvoice(data = {}) {
  return request.post('/invoice/apply',data)
}



// 查看登录用户发布的工作流
export function userPublishList(data = {}) {
  return request.get('/publish/userPublishList',data)
}

// 删除登录用户发布的工作流
export function delectPublish(data = {}) {
  return request.del(`/publish/${data}`)
}

// 余额记录
export function recordList(data = {}) {
  return request.get('/record/list',data)
}

// 部门列表
export function deptList(data = {}) {
  return request.get('/dept/list',data)
}

// 添加部门
export function applyDept(data = {}) {
  return request.post('/dept',data)
}

// 修改部门
export function uploadDept(data = {}) {
  return request.put('/dept',data)
}

// 删除部门
export function deleteDept(data = {}) {
  return request.del(`/dept/${data}`)
}

// 添加员工
export function addSubAccount(data = {}) {
  return request.post('/employee/addSubAccount',data)
}

// 给员工发送验证码
export function sendSubAccount(data = {}) {
  return request.post('/employee/sendSubAccount',data)
}

// 分配积分
export function allocatePoints(data = {}) {
  return request.put('/employee/allocatePoints',data)
}

// 计算可分配积分
export function getAvailablePoints(data = {}) {
  return request.get('/employee/getAvailablePoints',data)
}

// 删除员工
export function deleteSubAccount(data = {}) {
  return request.del(`/employee/deleteSubAccount/${data}`)
}
// 查询员工
export function employeeList(data = {}) {
  return request.get('/employee/list',data)
}
// 根据手机号查询员工
export function selectUserByPhone(data = {}) {
  return request.get('/auth/user/selectUserByPhone',data)
}

// 新增工单
export function issue(data = {}) {
  return request.post('/issue',data)
}
// 查询我的工单列b
export function issueList(data = {}) {
  return request.get('/issue/list',data)
}


// 删除工单
export function deleteIssue(data = {}) {
  return request.del(`/issue/${data}`)
}

// 查询问题列表
export function faqList(data = {}) {
  return request.get('/faq/list',data)
}
// 获取详情
export function getfaq(data = {}) {
  return request.del(`/faq/${data}`)
}

// 提现
export function applyWithdraw(data = {}) {
  return request.post('/withdraw/apply',data)
}

// 提现列b

export function withdrawList(data = {}) {
  return request.get('/withdraw/list',data)
}

// 创建ai相关账号
export function createAiAccount(data = {}) {
  return request.post('/workflow/user/createAiAccount',data)
}
